ExPostFacto.DataPoint (ex_post_facto v0.2.1)
View SourceDataPoint is a wrapper around data that represents an action taken, e.g. a buy or a sell.
Summary
Functions
Creates a new data point struct.
DataPoint is a wrapper around data that represents an action taken, e.g. a buy or a sell.
Creates a new data point struct.